@@ -2,12 +2,10 @@
 #include <R_ext/Rdynload.h>
 
 /* FIXME: 
-Check these declarations against the C/Fortran source code.
-*/
+ Check these declarations against the C/Fortran source code.
+ */
 
 /* .C calls */
-extern void bdmcmc_for_multi_dim(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void bdmcmc_map_for_multi_dim(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void dgm_bdmcmc_mpl_binary_ma(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void dgm_bdmcmc_mpl_binary_ma_multi_update(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void dgm_bdmcmc_mpl_binary_map(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
@@ -28,6 +26,10 @@ extern void gcgm_DMH_bdmcmc_map(void *, void *, void *, void *, void *, void *,
 extern void gcgm_DMH_bdmcmc_map_multi_update(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void gcgm_DMH_rjmcmc_ma(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void gcgm_DMH_rjmcmc_map(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void gcgm_dw_bdmcmc_ma(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void gcgm_dw_bdmcmc_ma_multi_update(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void gcgm_dw_bdmcmc_map(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void gcgm_dw_bdmcmc_map_multi_update(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void gcgm_rjmcmc_ma(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void gcgm_rjmcmc_map(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void ggm_bdmcmc_ma(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
@@ -51,17 +53,13 @@ extern void ggm_rjmcmc_mpl_map(void *, void *, void *, void *, void *, void *, v
 extern void log_exp_mc(void *, void *, void *, void *, void *, void *, void *, void *);
 extern void log_mpl_binary_parallel_hc(void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void log_mpl_dis(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void omp_set_num_cores(void *);
-extern void rcwish_c(void *, void *, void *, void *);
-extern void rgcwish_c(void *, void *, void *, void *, void *);
+extern void omp_set_num_cores(void *, void *);
 extern void rgwish_c(void *, void *, void *, void *, void *, void *);
 extern void rwish_c(void *, void *, void *, void *);
 extern void scale_free(void *, void *);
 extern void transfer_data(void *, void *, void *, void *, void *);
 
 static const R_CMethodDef CEntries[] = {
-    {"bdmcmc_for_multi_dim",                   (DL_FUNC) &bdmcmc_for_multi_dim,                   19},
-    {"bdmcmc_map_for_multi_dim",               (DL_FUNC) &bdmcmc_map_for_multi_dim,               22},
     {"dgm_bdmcmc_mpl_binary_ma",               (DL_FUNC) &dgm_bdmcmc_mpl_binary_ma,               12},
     {"dgm_bdmcmc_mpl_binary_ma_multi_update",  (DL_FUNC) &dgm_bdmcmc_mpl_binary_ma_multi_update,  13},
     {"dgm_bdmcmc_mpl_binary_map",              (DL_FUNC) &dgm_bdmcmc_mpl_binary_map,              16},
@@ -82,6 +80,10 @@ static const R_CMethodDef CEntries[] = {
     {"gcgm_DMH_bdmcmc_map_multi_update",       (DL_FUNC) &gcgm_DMH_bdmcmc_map_multi_update,       27},
     {"gcgm_DMH_rjmcmc_ma",                     (DL_FUNC) &gcgm_DMH_rjmcmc_ma,                     21},
     {"gcgm_DMH_rjmcmc_map",                    (DL_FUNC) &gcgm_DMH_rjmcmc_map,                    25},
+    {"gcgm_dw_bdmcmc_ma",                      (DL_FUNC) &gcgm_dw_bdmcmc_ma,                      21},
+    {"gcgm_dw_bdmcmc_ma_multi_update",         (DL_FUNC) &gcgm_dw_bdmcmc_ma_multi_update,         22},
+    {"gcgm_dw_bdmcmc_map",                     (DL_FUNC) &gcgm_dw_bdmcmc_map,                     25},
+    {"gcgm_dw_bdmcmc_map_multi_update",        (DL_FUNC) &gcgm_dw_bdmcmc_map_multi_update,        27},
     {"gcgm_rjmcmc_ma",                         (DL_FUNC) &gcgm_rjmcmc_ma,                         20},
     {"gcgm_rjmcmc_map",                        (DL_FUNC) &gcgm_rjmcmc_map,                        24},
     {"ggm_bdmcmc_ma",                          (DL_FUNC) &ggm_bdmcmc_ma,                          14},
@@ -105,9 +107,7 @@ static const R_CMethodDef CEntries[] = {
     {"log_exp_mc",                             (DL_FUNC) &log_exp_mc,                              8},
     {"log_mpl_binary_parallel_hc",             (DL_FUNC) &log_mpl_binary_parallel_hc,              9},
     {"log_mpl_dis",                            (DL_FUNC) &log_mpl_dis,                            10},
-    {"omp_set_num_cores",                      (DL_FUNC) &omp_set_num_cores,                       1},
-    {"rcwish_c",                               (DL_FUNC) &rcwish_c,                                4},
-    {"rgcwish_c",                              (DL_FUNC) &rgcwish_c,                               5},
+    {"omp_set_num_cores",                      (DL_FUNC) &omp_set_num_cores,                       2},
     {"rgwish_c",                               (DL_FUNC) &rgwish_c,                                6},
     {"rwish_c",                                (DL_FUNC) &rwish_c,                                 4},
     {"scale_free",                             (DL_FUNC) &scale_free,                              2},
